#property copyright "www.forex-station.com"
#property link      "www.forex-station.com"

#property indicator_chart_window
#property indicator_buffers 4
#property indicator_color1  clrYellow
#property indicator_color2  clrRed
#property indicator_color3  clrAqua
#property indicator_color4  clrYellow
#property indicator_width1  2
#property indicator_width2  2
#property indicator_width3  3  
#property indicator_width4  3 
#property strict  

//
//
//

input int                FastEMA         = 5;               // Fast ma period
input int                SlowEMA         = 100;             // Slow ma period
input ENUM_MA_METHOD     mamode          = MODE_LWMA;       // Ma type
input ENUM_APPLIED_PRICE maprice         = PRICE_CLOSE;     // Ma price
input int                RSIPeriod       = 21;              // Rsi period
input bool               ShowMaLine      = false;           // Show ma lines true/false?
input bool               alertsOn        = true;            // Alerts true/false?
input bool               alertsOnCurrent = false;           // Alerts open bar true/false?
input bool               alertsMessage   = true;            // Alerts message true/false?
input bool               alertsSound     = false;           // Alerts sound true/false?
input bool               alertsEmail     = false;           // Alerts email true/false?
input bool               alertsNotify    = false;           // Alerts notification true/false?
input string             soundFile       = "alert2.wav";    // Alerts Sound file

double buffer1[],buffer2[],buffer3[],buffer4[],trend[];

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+

int OnInit()
{
   IndicatorBuffers(5);
   SetIndexBuffer(0,buffer1,INDICATOR_DATA); SetIndexStyle(0,ShowMaLine ? DRAW_LINE : DRAW_NONE); 
   SetIndexBuffer(1,buffer2,INDICATOR_DATA); SetIndexStyle(1,ShowMaLine ? DRAW_LINE : DRAW_NONE); 
   SetIndexBuffer(2,buffer3,INDICATOR_DATA); SetIndexStyle(2,DRAW_ARROW); SetIndexArrow(2,233);
   SetIndexBuffer(3,buffer4,INDICATOR_DATA); SetIndexStyle(3,DRAW_ARROW); SetIndexArrow(3,234);
   SetIndexBuffer(4,trend);
   
return(INIT_SUCCEEDED);
}
void OnDeinit(const int reason){     }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+

int  OnCalculate(const int rates_total,const int prev_calculated,const datetime &time[],
                const double &open[],
                const double &high[],
                const double &low[],
                const double &close[],
                const long &tick_volume[],
                const long &volume[],
                const int &spread[])
{
   int i=rates_total-prev_calculated+1; if (i>=rates_total) i=rates_total-1;

   //
   //
   //
   
   for (;i>=0 && !_StopFlag; i--)
   {
      double rng  = 0; for (int k=0; k<10 && (i+k)<rates_total; k++) rng += high[i+k]-low[i+k]; rng /= 10.0;
      buffer1[i]  = iMA(_Symbol,_Period,FastEMA,0,mamode,maprice,i);
      buffer2[i]  = iMA(_Symbol,_Period,SlowEMA,0,mamode,maprice,i);
      double diff = (buffer1[i]-buffer2[i]);
      double rsi  = iRSI(_Symbol,_Period,RSIPeriod,PRICE_CLOSE, i);
      trend[i]    = (i<rates_total-1) ? (diff>0 && rsi>50) ? 1 : (diff<0 && rsi<50) ? -1 : trend[i+1] : 0; 
      
      buffer3[i] = buffer4[i] = EMPTY_VALUE;
      if (i<rates_total-1 && trend[i]!=trend[i+1])
       {
           if (trend[i] ==  1) buffer3[i] =  low[i] - rng*1.3;
           if (trend[i] == -1) buffer4[i] = high[i] + rng*1.3;
       }
         
   }
   
   //
   //
   //
   
   if (alertsOn)
   {
      int whichBar = (alertsOnCurrent) ? 0 : 1;
      if (trend[whichBar] != trend[whichBar+1])
      {
         if (trend[whichBar] == 1) doAlert(whichBar,"buy");
         if (trend[whichBar] ==-1) doAlert(whichBar,"sell");
      }         
   }
return(rates_total);
}

//
//
//

string sTfTable[] = {"M1","M5","M15","M30","H1","H4","D1","W1","MN"};
int    iTfTable[] = {1,5,15,30,60,240,1440,10080,43200};

string timeFrameToString(int tf)
{
   for (int i=ArraySize(iTfTable)-1; i>=0; i--) 
         if (tf==iTfTable[i]) return(sTfTable[i]);
                              return("");
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------

void doAlert(int forBar, string doWhat)
{
     static string   previousAlert="nothing";
     static datetime previousTime;
     string message;
   
     if (previousAlert != doWhat || previousTime != Time[forBar]) {
         previousAlert  = doWhat;
         previousTime   = Time[forBar];


          //
          //
          //
          //
          //

          message = timeFrameToString(_Period)+" "+_Symbol+" at "+TimeToStr(TimeLocal(),TIME_SECONDS)+" Rsi trend spotter "+doWhat;
             if (alertsMessage) Alert(message);
             if (alertsNotify)  SendNotification(message);
             if (alertsEmail)   SendMail(_Symbol+" Rsi trend spotter ",message);
             if (alertsSound)   PlaySound(soundFile);
      }
}


